==> qtjambi-qt3drender-6.2.11-sources.jar: io/qt/qt3d/render/QDebugOverlay.java <==
package io.qt.qt3d.render;


/**
 * <p>Enables a visual overlay with scene details</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3drender-qdebugoverlay.html">Qt3DRender::QDebugOverlay</a></p>
 */
public class QDebugOverlay extends io.qt.qt3d.render.QFrameGraphNode
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QDebugOverlay.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QDebugOverlay(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QDebugOverlay() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qdebugoverlay.html#QDebugOverlay">Qt3DRender::QDebugOverlay::QDebugOverlay(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QDebugOverlay(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QDebugOverlay instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QDebugOverlay(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QDebugOverlay(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QDebugOverlay instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-6.5.1-sources.jar: io/qt/qt3d/render/QDebugOverlay.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>Enables a visual overlay with scene details</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3drender-qdebugoverlay.html">Qt3DRender::QDebugOverlay</a></p>
 */
public class QDebugOverlay extends io.qt.qt3d.render.QFrameGraphNode
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QDebugOverlay.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QDebugOverlay(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QDebugOverlay() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qdebugoverlay.html#QDebugOverlay">Qt3DRender::QDebugOverlay::QDebugOverlay(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QDebugOverlay(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QDebugOverlay instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QDebugOverlay(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QDebugOverlay(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QDebugOverlay instance, QDeclarativeConstructor constructor);
    
}
